scopusreport
============

Create reports using Scopus data automatically in Python

Documentation: https://scopusreport.readthedocs.io

Development: https://github.com/scopus-api/scopus-report

.. image:: https://badge.fury.io/py/scopusreport.svg
    :target: https://badge.fury.io/py/scopusreport

.. image:: https://img.shields.io/pypi/pyversions/scopusreport.svg
    :target: https://img.shields.io/pypi/pyversions/scopusreport.svg

.. image:: https://readthedocs.org/projects/scopusreport/badge/?version=latest
    :target: https://readthedocs.org/projects/scopusreport/badge/?version=latest

.. image:: https://img.shields.io/pypi/l/scopusreport.svg
    :target: https://img.shields.io/pypi/l/scopusreport.svg

Change log
==========

Please see `CHANGES.rst <CHANGES.rst>`_.

Contributing
============

Please see `CONTRIBUTING.rst <CONTRIBUTING.rst>`_. For a list of contributors see
`AUTHORS.rst <AUTHORS.rst>`_.

License
=======

MIT License; see `LICENSE <LICENSE>`_.
